@@ -1,9 +1,9 @@
 import cherrypy
 import datetime
 import logging
-import six
-from six.moves import urllib
+import urllib.parse
 from girder import auditLogger
+from girder.constants import SortDir
 from girder.models.model_base import Model
 from girder.api.rest import getCurrentUser
 from girder.plugin import GirderPlugin
@@ -12,6 +12,11 @@ from girder.plugin import GirderPlugin
 class Record(Model):
     def initialize(self):
         self.name = 'audit_log_record'
+        compoundFilterIndex = (
+            ('when', SortDir.ASCENDING),
+            ('type', SortDir.ASCENDING)
+        )
+        self.ensureIndices([(compoundFilterIndex, {}), 'type', 'when'])
 
     def validate(self, doc):
         return doc
@@ -31,7 +36,7 @@ class _AuditLogDatabaseHandler(logging.Handler):
             record.details['params'] = {
                 # 'urllib.parse.quote' alone doesn't replace '.'
                 urllib.parse.quote(paramKey, safe='').replace('.', '%2E'): paramValue
-                for paramKey, paramValue in six.viewitems(record.details['params'])
+                for paramKey, paramValue in record.details['params'].items()
             }
         Record().save({
             'type': record.msg,
@@ -43,7 +48,7 @@ class _AuditLogDatabaseHandler(logging.Handler):
 
 
 class AuditLogsPlugin(GirderPlugin):
-    DISPLAY_NAME = 'Audit logging'
+    DISPLAY_NAME = 'Audit Logging'
 
     def load(self, info):
         auditLogger.addHandler(_AuditLogDatabaseHandler())
